==> istio-model-v1beta1-5.11.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WorkloadEntrySpecBuilder extends io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluentImpl<io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec,io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecBuilder>{
  public WorkloadEntrySpecBuilder() {
    this(false);
  }
  public WorkloadEntrySpecBuilder(java.lang.Boolean validationEnabled) {
    this(new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec instance) {
    this(fluent, instance, false);
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluent<?> fluent,io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withLocality(instance.getLocality()); 
    fluent.withNetwork(instance.getNetwork()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withServiceAccount(instance.getServiceAccount()); 
    fluent.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec instance) {
    this(instance,false);
  }
  public WorkloadEntrySpecBuilder(io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withLabels(instance.getLabels()); 
    this.withLocality(instance.getLocality()); 
    this.withNetwork(instance.getNetwork()); 
    this.withPorts(instance.getPorts()); 
    this.withServiceAccount(instance.getServiceAccount()); 
    this.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1beta1.WorkloadEntrySpec build() {
    WorkloadEntrySpec buildable = new WorkloadEntrySpec(fluent.getAddress(),fluent.getLabels(),fluent.getLocality(),fluent.getNetwork(),fluent.getPorts(),fluent.getServiceAccount(),fluent.getWeight());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadEntrySpecBuilder that = (WorkloadEntrySpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1beta1-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/WorkloadEntrySpecBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WorkloadEntrySpecBuilder extends WorkloadEntrySpecFluentImpl<WorkloadEntrySpecBuilder> implements VisitableBuilder<WorkloadEntrySpec,WorkloadEntrySpecBuilder>{
  public WorkloadEntrySpecBuilder() {
    this(false);
  }
  public WorkloadEntrySpecBuilder(Boolean validationEnabled) {
    this(new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WorkloadEntrySpec(), validationEnabled);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance) {
    this(fluent, instance, false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpecFluent<?> fluent,WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAddress(instance.getAddress()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withLocality(instance.getLocality()); 
    fluent.withNetwork(instance.getNetwork()); 
    fluent.withPorts(instance.getPorts()); 
    fluent.withServiceAccount(instance.getServiceAccount()); 
    fluent.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance) {
    this(instance,false);
  }
  public WorkloadEntrySpecBuilder(WorkloadEntrySpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAddress(instance.getAddress()); 
    this.withLabels(instance.getLabels()); 
    this.withLocality(instance.getLocality()); 
    this.withNetwork(instance.getNetwork()); 
    this.withPorts(instance.getPorts()); 
    this.withServiceAccount(instance.getServiceAccount()); 
    this.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  WorkloadEntrySpecFluent<?> fluent;
  Boolean validationEnabled;
  public WorkloadEntrySpec build() {
    WorkloadEntrySpec buildable = new WorkloadEntrySpec(fluent.getAddress(),fluent.getLabels(),fluent.getLocality(),fluent.getNetwork(),fluent.getPorts(),fluent.getServiceAccount(),fluent.getWeight());
    return buildable;
  }
  
}
